# `beautiful`
[![pypi](https://badge.fury.io/py/beautiful.svg)](https://pypi.python.org/pypi/beautiful/)
[![Made with Python](https://img.shields.io/pypi/pyversions/beautiful)](https://www.python.org/)
[![Type hinted - mypy validated](https://img.shields.io/badge/typehinted-yes-teal)](https://github.com/kalaspuff/beautiful)
[![MIT License](https://img.shields.io/github/license/kalaspuff/beautiful.svg)](https://github.com/kalaspuff/beautiful/blob/master/LICENSE)
[![Code coverage](https://codecov.io/gh/kalaspuff/beautiful/branch/master/graph/badge.svg)](https://codecov.io/gh/kalaspuff/beautiful/tree/master/beautiful)

*A collection of functions and classes to aid developers into building better code faster.*


## Installation with `pip`
Like you would install any other Python package, use `pip`, `poetry`, `pipenv` or your weapon of choice.
```
$ pip install beautiful
```


## Usage and examples

#### Use-case
```
import beautiful

```
